@@ -17,7 +17,7 @@
 
 import bz2
 import urllib
-import StringIO
+import cStringIO
 
 
 import conf
@@ -30,7 +30,7 @@ def open_packages_url(url):
     assert url.endswith(".bz2")
     socket = urllib.urlopen(url)
     decompressor = bz2.BZ2Decompressor()
-    file = StringIO.StringIO()
+    file = cStringIO.StringIO()
     while True:
         data = socket.read(1024)
         if not data:
